#!/bin/bash -e
#
# Copyright 2015 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

version="$1"
if [ -z "$version" ]; then
	echo "usage: $0 <version>"
	exit 1
fi

ARCH=$(dpkg --print-architecture)
base_image_basename="univention/ucs-minbase-${ARCH}"
base_image_latest="${base_image_basename}:latest"
base_image_versioned="${base_image_basename}:$1"
resultimage_name="univention/ucs-appbox-${ARCH}:$1-minbase"

image_name_is_available() {
	local image_name
	local image_uuid
	image_name="$1"
	image_uuid=$(docker inspect --format='{{.Id}}' "$image_name" 2>/dev/null || true)
	if [ -n "$image_uuid" ]; then
		echo -e "ERROR: Docker image name $image_name already exists. UUID: $image_uuid"
		echo -e "ERROR: That name cannot be assigned to the new image."
		echo -e "INFO:  Consider assigning an alternative tag to the existing image:"
		echo -e "INFO:  \tdocker tag $image_name othername1"
		echo -e "INFO:  After that you may free the name my running:"
		echo -e "INFO:  \tdocker rmi $image_name"
		return 1
	fi
	return 0
}

if ! image_name_is_available "$resultimage_name"; then
	exit 1
fi

temp_dockerfile_dir="$(mktemp -d ${TMPDIR:-/var/tmp}/docker-build.XXXXXXXXXX)"
cleanup () {
	echo "Removing temporary $temp_dockerfile_dir"
	rm -rf "$temp_dockerfile_dir"
}
trap cleanup EXIT

cp -r /usr/share/univention-docker-dev/build/appbox-minbase/* "$temp_dockerfile_dir"

## If the Dockerfile has a "latest" dependency, replace it with the versioned one:
sed -i "s|^FROM ${base_image_latest}$|FROM ${base_image_versioned}|" "$temp_dockerfile_dir/Dockerfile"

exec > >(tee ucs-appbox-minbase.log) 2>&1
grep ^FROM "$temp_dockerfile_dir/Dockerfile"
time docker build -t "$resultimage_name" "$temp_dockerfile_dir"
if [ $? = 0 ]; then
	echo "Finished building $resultimage_name"
else
	trap - EXIT
fi 
