#!/bin/bash -e
#
# Copyright 2015 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

PATH="$PATH:/usr/share/univention-docker-dev/scripts"

ARCH=$(dpkg --print-architecture)

argv0="$0"
usage() {
	echo >&2 "usage: $argv0"
	exit 1
}

opttemp=$(getopt --options '+f' --longoptions 'force,help' --name "$argv0" -- "$@")
eval set -- "$opttemp"
unset opttemp

unset force
while true; do
	case "$1" in
		-f|--force)
			force=1
			shift
			;;
		--help)
			usage;
			;;
		--)
			shift;
			break
			;;
		*)
			usage;
			;;
	esac
done

if [ $# -gt 0 ]; then
	usage
fi

if [ "$force" = 1 ]; then
	for role in member slave master generic; do
		for version in latest 4.0-2 4.0-1 4.0-0; do
			docker rmi "univention/ucs-${role}-${ARCH}:${version}" || true
			docker rmi "univention/ucs-${role}-${ARCH}:${version}" || true
			docker rmi "univention/ucs-${role}-${ARCH}:${version}" || true
		done
	done
	docker rmi "univention/ucs-stem-${ARCH}:4.0-0" || true
	docker rmi "univention/ucs-appbox-${ARCH}:4.0-0" || true
fi

### First build ucs-stem-${ARCH}:4.0-0
create-docker-ucs-stem-image.sh http://updates.software-univention.de/4.0/maintained/4.0-0/

### Then build the role layers
for role in member slave master; do
	create-docker-ucs-role-image.sh "univention/ucs-stem-${ARCH}:4.0-0" "$role"
done

### Also build the ucs-generic-${ARCH}:4.0-0 image (without stem):
create-docker-ucs-appliance-image.sh  http://updates.software-univention.de/4.0/maintained/4.0-0/

### Then build the 4.0-1 and 4.0-2 update layers
for base_version in 4.0-0 4.0-1; do
	for role in member slave master generic; do
		update-docker-ucs-appliance-image.sh \
			"univention/ucs-${role}-${ARCH}:${base_version}"
	done
done

### Also build the "AppBox" image (Member only currently)
create-docker-ucs-appbox-image.sh http://updates.software-univention.de/4.0/maintained/4.0-0/

### Finally tag the "latest"
for role in member slave master generic; do
	docker tag "univention/ucs-${role}-${ARCH}:4.0-2" \
		"univention/ucs-${role}-${ARCH}:latest"
done

docker tag "univention/ucs-appbox-${ARCH}:4.0-0" \
	"univention/ucs-appbox-${ARCH}:latest"

for version in 4.0-0; do
	## 1. Create ucs-minbase image via debootstrap
	docker rmi "univention/ucs-minbase-${ARCH}:${version}" || true
	create-minbase-image.sh http://updates.software-univention.de/4.0/maintained/${version}/

	## For convenience tag this image as latest
	docker rmi "univention/ucs-minbase-${ARCH}:latest" || true
	docker tag "univention/ucs-minbase-${ARCH}:${version}" \
		"univention/ucs-minbase-${ARCH}:latest"

	## 2. Create ucs-appbox-minbase image via Dockerfile
	docker rmi "univention/ucs-appbox-${ARCH}:${version}-minbase" || true
	create-appbox-minbase-image.sh "${version}"
done
