#!/bin/bash -e
#
# Copyright 2015 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

ucsapp_namespace="ucsapp"

# Create a docker image from a base image and an app

docker_image_pkg_arch=$(/usr/bin/dpkg --print-architecture)
argv0="$0"
usage() {
	echo >&2 "usage: $argv0 [-i <result image name>] <base image name> <app name>"
	echo >&2 " e.g.: $argv0 univention/ucs-member-$docker_image_pkg_arch:4.0-1 someapp"
	exit 1
}

opttemp=$(getopt --options '+i:h' --longoptions 'name:,image:,resultimagename:,help' --name "$argv0" -- "$@")
eval set -- "$opttemp"
unset opttemp

unset resultimage_name
docker_run_options=( '-d' )
while true; do
	case "$1" in
		-i|--image|--resultimagename)
			resultimage_name="$2";
			shift 2;
			;;
		--name|--containername)
			docker_run_options+=("--name" "$2");
			shift 2;
			;;
		-v|--volume)
			docker_run_options+=("-v" "$2");
			shift 2;
			;;
		--help)
			usage;
			;;
		--)
			shift;
			break;
			;;
	esac
done

base_image_name="$1"
if [ -z "$base_image_name" ]; then
	usage
fi
shift

app_name="$1"
if [ -z "$app_name" ]; then
	usage
fi
shift

app_container_var_dir="/var/lib/appcenter/$app_name"
app_container_data_dir="$app_container_var_dir/data"
# app_container_config_dir="$app_container_var_dir/config"
# app_container_etc_dir="$app_container_config_dir/etc"
# app_container_etc_univention_dir="$app_container_etc_dir/univention"

# mkdir -p "$app_container_etc_univention_dir"
## at least touch the files, otherwise docker creates them as directories:
# for fn in base.conf base-forced.conf base-ldap.conf base-schedule.conf; do
# 	touch "$app_container_etc_univention_dir/$fn"
# done
# touch "$app_container_etc_dir/machine.secret"

docker_run_options+=("-v" "$app_container_data_dir:$app_container_data_dir")
# -v "$app_container_config_dir/etc/univention/ssl":"/etc/univention/ssl"
# -v "$app_container_config_dir/etc/machine.secret":"/etc/machine.secret"
# -v "$app_container_config_dir/etc/univention/base.conf":"/etc/univention/base.conf"
# -v "$app_container_config_dir/etc/univention/base-forced.conf":"/etc/univention/base-forced.conf"
# -v "$app_container_config_dir/etc/univention/base-ldap.conf":"/etc/univention/base-ldap.conf"
# -v "$app_container_config_dir/etc/univention/base-schedule.conf":"/etc/univention/base-schedule.conf"

uuid=$(docker run \
	"${docker_run_options[@]}" \
	"$base_image_name" \
	/sbin/init)
echo "UUID: $uuid"

## Wait for ((UCR committed resolv.conf) and (runlevel 2))
echo -n "INFO: Waiting for container runlevel 2 "
for ((i=0;i<30;i++)); do
	sleep 1	## first wait, the /sbin/init wrapper needs to reset utmp
	echo -n "."
	read clvl rlvl < <(docker exec "$uuid" runlevel)
	if [ "$rlvl" = 2 ]; then
		break 2
	fi
done
if [ "$i" -eq 30 ]; then
	echo "Timeout"
	exit 1
else
	echo "Ok"
fi

## And now we run additional commands in the container:
docker exec "$uuid" bash -c 'DEBIAN_FRONTEND=noninteractive univention-install -y univention-management-console-module-appcenter python-simplejson'

## Patch univention-add-app to continue w/o license check
docker exec "$uuid" sed -i '/if not LICENSE.allows_using/,+2{$!{N;s/\(.*\)sys.exit\(.*\)/\1# sys.exit\2/;ty;P;D;:y}}' /usr/sbin/univention-add-app

## Install app
docker exec "$uuid" ucr set repository/online=true
docker exec "$uuid" /usr/sbin/univention-add-app --latest --all "$app_name"

## Cleanup
# docker exec "$uuid" /etc/init.d/univention-management-console-server stop
docker exec "$uuid" bash -c 'DEBIAN_FRONTEND=noninteractive apt-get purge --auto-remove --yes univention-management-console-module-appcenter python-simplejson'
docker exec "$uuid" apt-get clean
docker exec "$uuid" find /var/lib/apt/lists -type f -exec rm {} +

## Disable the gettys (could be done in UCS base image as well)
docker exec "$uuid" sed -i -E 's|(^[1-6]:.*:.*/sbin/getty .*)|#\1|' /etc/inittab

## Halt the container processes
docker stop "$uuid"

if [ -z "$resultimage_name" ]; then
	resultimage_name="$ucsapp_namespace/$app_name-$docker_image_pkg_arch"
	## Append the tag of the base image if present
	base_image_tagstring="${base_image_name#*:}"
	if [ -n "$base_image_tagstring" ]; then
		resultimage_name="$resultimage_name:$base_image_tagstring"
	fi
fi

docker commit "$uuid" "$resultimage_name" && \
  echo -e "The new image has been generated: $resultimage_name" && \
  echo -e "Now you can remove the temporary container by running:\n\tdocker rm '$uuid'"
