#!/bin/bash -e
#
# Copyright 2015 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

argv0="$0"
usage() {
	echo >&2 "usage: $argv0"
	exit 1
}

opttemp=$(getopt --options '+h' --longoptions 'really,help' --name "$argv0" -- "$@")
eval set -- "$opttemp"
unset opttemp

unset really
while true; do
	case "$1" in
		--really)
			really=1
			shift
			;;
		-h|--help)
			usage;
			;;
		--)
			shift;
			break
			;;
		*)
			usage;
			;;
	esac
done

if [ $# -gt 0 ]; then
	usage
fi

if ! [ "$really" = 1 ]; then
	echo "To really upload specify --really"
	exit 2
fi

ARCH=$(dpkg --print-architecture)

login="$(sed -n 's/login: //p' < /etc/docker_hub.credentials)"
password="$(sed -n 's/password: //p' < /etc/docker_hub.credentials)"
docker login -u univention -p "$password" -e "$login"

docker push "univention/ucs-stem-${ARCH}:4.0-0"

for role in generic master slave member; do
	for version in 4.0-0 4.0-1 4.0-2 latest; do
		docker push "univention/ucs-${role}-${ARCH}:${version}"
		docker push "univention/ucs-${role}-${ARCH}:${version}"
		docker push "univention/ucs-${role}-${ARCH}:${version}"
	done
done

docker push "univention/ucs-appbox-${ARCH}:4.0-0"
docker push "univention/ucs-appbox-${ARCH}:latest"

for version in 4.0-0; do
	docker push "univention/ucs-minbase-${ARCH}:${version}"
	docker push "univention/ucs-appbox-${ARCH}:${version}-minbase"
done
